#' tidytreatment: Tidy methods for Bayesian treatment effect models
#'
#' tidytreatment provides functions for extracting tidy data from Bayesian treatment effect models, estimating treatment effects, and plotting useful summaries of these.
#'
#' @name tidytreatment
#' @importFrom tidybayes fitted_draws predicted_draws residual_draws add_predicted_draws add_fitted_draws add_residual_draws
#' @importFrom tidybayes epred_draws linpred_draws tidy_draws
#' @importFrom stats rnorm predict terms
#' @importFrom rlang := !! .data
#' @importFrom utils methods
#' @importFrom dbarts extract
#'
"_PACKAGE"
